@@ -1,4 +1,4 @@
-from django_mistune.plugins import HeaderLevels, AddClasses
+from django_mistune.plugins import AddClasses, HeaderLevels, TargetBlankLinks
 
 USE_TZ = True  # Avoid deprecation warning
 
@@ -15,5 +15,8 @@ TEMPLATES = [
 MISTUNE_STYLES = {
     "noescape": {"escape": False},
     "headers": {"plugins": [HeaderLevels(3)]},
-    "classes": {"plugins": [AddClasses({"p": ("a", "b"), "em": "c"})]},
+    "classes": {
+        "plugins": [AddClasses({"p": ("a", "b"), "em": "c", "img": "d"})]
+    },
+    "links": {"plugins": [TargetBlankLinks()]},
 }
